/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import org.ow2.bonita.facade.def.element.ExternalReferenceDefinition;
import org.ow2.bonita.facade.def.element.RoleMapperDefinition;
import org.ow2.bonita.facade.def.element.impl.ExternalReferenceDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.RoleMapperDefinitionImpl;
import org.ow2.bonita.facade.def.majorElement.ParticipantDefinition;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ParticipantDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;


public class ParticipantDefinitionImpl extends ProcessDefinitionRecordImpl implements ParticipantDefinition {

  /**
   * 
   */
  private static final long serialVersionUID = 72293066997775691L;
  protected ParticipantDefinitionUUID uuid;
  protected String participantId;
  protected String description;
  protected ExternalReferenceDefinition externalReference;
  protected ParticipantType participantType;
  protected RoleMapperDefinition roleMapper;

  protected ParticipantDefinitionImpl() { }

  public ParticipantDefinitionImpl(ParticipantDefinitionUUID uuid,
      String participantId, PackageDefinitionUUID packageUUID, ProcessDefinitionUUID processUUID,
      String description, RoleMapperDefinition roleMapper, ExternalReferenceDefinition externalReference,
      ParticipantType participantType, String name) {
    super(packageUUID, name, processUUID);
    this.uuid = uuid;
    this.participantId = participantId;
    this.description = description;
    this.roleMapper = roleMapper;
    this.externalReference = externalReference;
    this.participantType = participantType;
  }

  public ParticipantDefinitionImpl(ParticipantDefinition src) {
    super(src);
    this.uuid = new ParticipantDefinitionUUID(src.getUUID());
    this.participantId = src.getParticipantId();
    this.description = src.getDescription();
    if (src.getExternalReference() != null) {
      this.externalReference = new ExternalReferenceDefinitionImpl(src.getExternalReference());
    }
    this.participantType = src.getParticipantType();
    this.name = src.getName();
    if (src.getRoleMapper() != null) {
      this.roleMapper = new RoleMapperDefinitionImpl(src.getRoleMapper());
    }
  }

  public String getDescription() {
    return description;
  }

  public ExternalReferenceDefinition getExternalReference() {
    return externalReference;
  }

  public ParticipantType getParticipantType() {
    return participantType;
  }

  public String getName() {
    return name;
  }

  public RoleMapperDefinition getRoleMapper() {
    return roleMapper;
  }

  public String getParticipantId() {
    return participantId;
  }

  public ParticipantDefinitionUUID getUUID() {
    return uuid;
  }
}


